# package_name

Description. 
The package package_name is used to:
	- Projeto criado para o Bootcamp Geracao Tech Unimed - BH - Ciencias de Dados
	- Criacao de uma aplicação em Python de uma calculadora com funcoes basicas.
	- Demonstracao da criação de um pacote para o projeto.
	- Demonstracao da modularizacao da aplicacao.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install package_calculadora
```

## Usage

```python
from package_calculadora import calculadora
calculadora.sub_numbers ()
calculadora.add_numbers()
calculadora.div_numbers()
calculadora.mult_numbers()
```

## Author
Adriana Andrade

## License
[MIT](https://choosealicense.com/licenses/mit/)